% PCI1H.m : Plankton Index script using Convex Hull with outlier exclusion
%
% The Plankton Index (PI) was oroginally called the PCI
% Paul Tett, Napier University, 8 - 9 August 2009:
%   starting from PCI1ED3  (mainly 6-12 August 2008 for Matlab 7.1,
%   but updated 8 Aug 2009 for Matlab 7.8)
% version F allows some points to be excluded from reference envelope
% User will need to change the name of the curent working directory
%   --- see line (approx) 75 
% This working directory must contain all necessary script, function,
%   and data files
% After April 2010, Paul Tett, SAMS
% Using on Windows under Matlab 7.12: 15 Aug 2011 
%   Minor changes, 19 Nov 2011
%   improvements in envelope fit and plotting, 20 May 2013 [v.b]
%   added ability to change cp.sc (scaling) between runs: 5 Oct 13
%   add option for state space plots of medians: 6 Oct 13 
%   add ability to change reference years between runs: 7 Oct 13
% version G (started 23 October 2013) loads only one data file
% version ..GTh started 2014 for Thau lagoon (PT)
% PT 1 Mar 2015, calls TSPLOT2 (which includes ratios)
% version ....H started PT, 23 July 2015, to include option for many PIs
%   Outputs/comments now refer to PI, but variable names still include PCI
%   Input (data) and output (diagrams) folders used (25 July 2015)
%   Subfolder also used for Cf3 parameter files
% PT, 5 Sep 2015 - calls SSPLOT2 rather than SSPLOTTH or earlier SSPLOT
% PT, 7 Sep 2015 - modified calls of EXTRACT to deal with biomass and no.
% PT, 12 Sep 2015 - all displays of 'PCI' changed to 'PI'
% ===============================================================
% SUMMARY OF PCI1H
%
% 1. Include control data script CF3THAU.M to provide default
%       file names and parameter values in the structure CP
%
% 2. Load one ASCII text data fils, in which the first
%       column is date.dec and subsequent columns are the 
%       'state variables' - i.e. the abundances of lifeforms
%
% 3. Present the 'central menu' of operations, of which one
%       is 'exit the program'; the others are:
%  
% 4. Plot time-series of the data with function TSPLO2T.M
%       which was added 1 Mar 2015
%
% 5. Extract a reference data set using EXTRACT2.M,
%       and fit the doughnut-like envelope using FINDENV2.M,
%       ******** called with p <= 1.0 to set fraction of data used;
%               (8 Aug 09: replaces FINDENV.M)
%       if required for random subsampling, repeat NREFMAX times,
%       putting the data in the cell array REFD{1:NREFMAX},
%       and the envelope co-ordinates 
%       in the cell array REFENV{1:NREFMAX}
%
% 6. Extract a comparison data set using EXTRACT2.M;
%       compare with reference doughnut and calculate PI
%       using PCICALC2.M; (9 Aug 09: replaces PCICALC.M)
%       if required by random subsampling, repeat NCOMPMAX times,
%       putting the data in the cell array COMPD{1:NCOMPMAX}
%       and the PCI data in the cell array PCIDAT{1:NCOMPMAX}
%
% 7. If REFD, REFENV, COMPD and PCID exist, call PIPLOT2.M
%       (25 July 2015: replaced PCIPLOT)
%       to plot a PI diagram,
%       comparing one reference and one comparison data set;
%       with colour or B&W options.
%
% 8. Change some of the control parameters in structure CP
%       using CCP (new function, 25 July 2015) (uses GETNUM.M)
%
% 9. [NEW OPTION 6 Oct 13} SSPLOT.M makes a state-space plot of medians
%       and calculates and plots Euclidian distance from reference
%
% 10. [NEW OPTION, 23 July 15] to calculate and plot a time-series of 
%       annual values of the PI: calls PITS.M

% ===============================================================

% 
	clear all;% all variables
	close all;% figure windows
    continueflag=1;
%
    global prog_name uname
    prog_name = mfilename;
    
    pause off; % on allows delay before switching windows
    % set this to off if you want faster execution
%
% User to set current working directory 
%       - to where user keeps program and data files
%    cd('/Applications/MATLAB71/Paulmfiles/PCI/NEWAUG08'); % Mac OS X
%    cd('/Users/Shared/PaulmfilesMay09/PCI/PCINEWAUG09'); % MacBook
   cd('C:\Users\sa02pt\Documents\MATLAB\PCI2015');% Windows
%
    fprintf('\n%s\n', ...
        '*********************************************************');
    fprintf('%s\n', [prog_name ' started: ' datestr(now)]);
    fprintf('%s\n', 'abort with ctrl-C, ctrl-break or <apple>-<.>');
    fprintf('%s\n\n', ['Current directory is ' pwd]);
%
% 1. Include control data from the following (script) m-file
% --------------------------------------------------------
oldfolder = cd('params');
% The script cf3 should be edited for each PI calculation task;
%   it can be renamed (e.g. cf3Thau) - in which case, edit next line
    cf3; % contains run parameters in a structure called cp
cd(oldfolder); % restore main working directory
%
% 2. Load the data file
% ----------------------
% check on existence of data file specified by cf3
% give user opportunity to change the names ?
% load the data file 
fn = ['data' filesep cp.df1n];
if exist(fn, 'file'),
    data1 = load(fn, '-ascii');
    fprintf('%s\n', ['Loaded data file '  cp.df1n ' for ' cp.d1des]);
    % calculate some statistics
    if cp.c1svt1 == 1, % using cell numbers as variables
        cp.maxn = max( max(log10(data1(:,cp.c1sv1)+cp.z1)), ...
            max(log10(data1(:,cp.c1sv2)+cp.z2)) );  
        cp.maxb = NaN;
        fprintf('%s%5.2f\n', ' -- Maximum log10(cells/L) = ', cp.maxn);
    else % using biovolumes as variables
         cp.maxb = max( max(log10(data1(:,cp.c1sv1)+cp.bz1)), ...
            max(log10(data1(:,cp.c1sv2)+cp.bz2)) );  
        cp.maxn = NaN;
  fprintf('%s%5.2f\n', ' -- Maximum biovolume, log10(mm3/L) = ', cp.maxb);
    end 
else
    fprintf('%s\n', ['Cannot find ' cp.df1n 'in' pwd filesep 'data']);
    fprintf('%s\n', 'Ending the run ....');
    continueflag = 0;
end
fprintf('\n');
%
if continueflag > 0,
    duname='XX';
    uname=input(['Enter your 2-letter ID, e.g. [' duname ']: '], 's');
    if isempty(uname), uname=duname; end
    fprintf('\n');
end   
    
% 3. The central menu
% -------------------
% 
refflag=0; % reference envelope does not initially exist
PCIflag=0; % comparison data and PI do not initially exist
while continueflag,
    pause(1); % wait a second, then
    commandwindow; % selects command window (brings to front) ?
    fprintf('%s\n', '------------- MAIN MENU FOR PI ----------------');
    fprintf('%s\n', ['End ' prog_name ' (0)']);
    fprintf('%s\n', '    Plot data time-series (1)');
    fprintf('%s\n', '        Make reference envelope (2)');
    if refflag > 0.5,
        fprintf('%s\n', '           single PI for comparison data (3)');
        fprintf('%s\n', '           annual PI time-series (7)');
        if PCIflag > 0.5,
            fprintf('%s\n', '               Plot PI diagram (4)');
        end
    end
    fprintf('%s\n', '        Change values of control parameters (5)');
    fprintf('%s\n', '    Make state space plot of annual medians (6)');
    defaf = 0;
    actionflag=input(['Enter a number [' num2str(defaf) ']: ']);
    if isempty(actionflag), actionflag=defaf; end
    fprintf('%s\n\n', '------------------------------------');
    %
    % ============================== START SWITCH ON ACTIONFLAG ===
    switch actionflag
        %
        %
        case 0 % ------------------------------------------
            fprintf('%s\n', ...
         '--- ending program (please remove your output files) ...');
            continueflag = 0;
            %
            %
        case 1 % ------------------------------------------
%
% 4. Plot data-time-series
% ------------------------
%
            tsplot2(data1, cp);% cp is structure with controls
            %
            %
        case 2 % ------------------------------------------
%
% 4. Make reference envelope
% -------------------------
%
            %
            fprintf('%s\n', ...
                    ['Fitting reference envelopes with mf = ', ...
                                    num2str(cp.mf)]);
            mess = [cp.d1des ' from file ' cp.df1n];
            fprintf('%s\n', ['  to data for ' mess]);      
            % ensure that selection years are correctly formatted
            ref_start = floor(cp.refs);
            ref_end = floor(cp.refe) + 0.999;
            fprintf('%s\n', ['  for years: ' num2str(ref_start) ...
                                ' to ' num2str(floor(cp.refe))]);
            % set up the loop
            if cp.mfref > 0.5 && cp.mf < 0,
                % multiple subsampling of reference data
                nrefmax = cp.mfn;
            else
                % all other cases
                nrefmax = 1;
            end
            % dimension cell arrays for data and envelopes
            envd = cell(nrefmax); 
            refenv = cell(nrefmax, 2); 
            % do the loop
            for nref = 1:nrefmax,
            % extract data for the reference years
                if cp.c1svt1 == 1, % dealing with numbers
                    refd{nref} =  extract2(...
                        ref_start, ref_end, cp.z1, cp.z2, ...
                            data1, cp.c1dat, cp.c1sv1, cp.c1sv2, cp.mf);
                else % dealing with biomass
                    refd{nref} =  extract2(...
                        ref_start, ref_end, cp.bz1, cp.bz2, ...
                            data1, cp.c1dat, cp.c1sv1, cp.c1sv2, cp.mf);
                end
                % get envelope
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                % 8 Aug 09 - call findenv2, which will exclude cp.p 
                % fraction outliers, and may return a modified cp.p
                % 20 May 13 - cp.sc = 1 causes axes scaling
                [envO, envI, cp.p ] = findenv2(...
                    refd{nref}(:,2), refd{nref}(:,3), cp.p, cp.sc);
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                refenv{nref, 1} = envO; % outer envelope
                refenv{nref, 2} = envI; % inner envelope
                % each envelope is a 2 column array, 
                %   for X and Y co-ordinates
            end % nref loop
            refflag = 1; % now that envelopes exist
            fprintf('%s\n\n', ...
                ['--- made ' num2str(nrefmax) ' envelope pair(s)']);
            %
            %
        case 3 % ------------------------------------------         
%
% 5. Get comparison data and calculate PI
% -------------------------
%
        % check for existence of necessary data
        if refflag < 0.5,
            fprintf('%s\n', '--> I can''t do that yet, Dave');
        else
            fprintf('%s\n', ...
                    ['Estimating PI with mf = ', num2str(cp.mf)]);
            mess = [cp.d1des ' from file ' cp.df1n];
            fprintf('%s\n', ['  using data for ' mess]);
            % get extra parameters
            if nrefmax > 1,
                % find out what pair of envelopes is to be used
                 fprintf('%s\n', ['A set of ' ...
                     num2str(nrefmax) ' envelopes exists;']);
                 usenvn = getnum ...
                     ('  choose envelope pair number', nrefmax);
                 if usenvn > nrefmax, usenvn = nrefmax; end
                 if usenvn < 1, usenvn = 1; end
            else
                usenvn=1;
            end
            if cp.mf < 0, % random subsampling required
                ncompmax = cp.mfn;
            else
                ncompmax = 1;
            end
            % dimension arrays for data and results
            compd = cell(ncompmax); % cell aray
            PCIdat = zeros(ncompmax,7);
            % get the range of years for which data will be selected
            years = unique(floor(data1(:,1)));
            minyear = min(years); maxyear = max(years);
            fprintf('%s\n', 'Select range of years for PCI:');
            comp_start = floor(getnum(...
                'Enter (integer) start year', minyear));
            if comp_start < minyear, comp_start = minyear; end
            if comp_start > maxyear, comp_start = maxyear; end
            comp_end = floor(getnum(...
                'Enter (integer) end year', maxyear)) + 0.999;
         if comp_end < comp_start, comp_end = comp_start + 0.999; end
            if comp_end > maxyear, comp_end = maxyear + 0.999; end
            fprintf('%s\n\n', ['--- using the year range: ' ...
                num2str(comp_start) ' to ' num2str(comp_end)]);
            %
            fprintf(...
    '   year range         PI    N-total N-out  binom p  chi-sq \n');
            % begin loop
            for ncomp = 1:ncompmax,
                % extract data for the reference years
                if cp.c1svt1 == 1, % dealing with numbers
                    compd{ncomp} =  extract2(...
                        comp_start, comp_end, cp.z1, cp.z2,...
                            data1, cp.c1dat, cp.c1sv1, cp.c1sv2, cp.mf);
                else % dealing with biomass
                    compd{ncomp} =  extract2(...
                        comp_start, comp_end, cp.bz1, cp.bz2,...
                            data1, cp.c1dat, cp.c1sv1, cp.c1sv2, cp.mf);
                end
                % call the PCI function
                PCIdat(ncomp,1) = comp_start;
                PCIdat(ncomp,2) = comp_end;
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                % updated 9 Aug 09 to use PCIcalc2 and pass fraction cp.p
                PCIdat(ncomp,3:7) = PCIcalc2(compd{ncomp}, ...
                        refenv{usenvn,1}, refenv{usenvn,2}, cp.p);
                % returns: PCI, n-total, n-out, binom sig, chi-sq 
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                fprintf(...
                  '%8.2f %8.2f %8.2f %6.0f %6.0f %8.4f %8.2f \n', ...
                    PCIdat(ncomp,:) );
            end % of ncomp loop
            PCIflag = 1; % now that PI has/have been calculated
            if ncompmax > 1,
                % compute some statistics
                medPCI = median(PCIdat(:,3));
                medbp = median(PCIdat(:,6));
                fprintf(...
        '---- median PI = %8.2f     binom p = %8.4f -------- \n', ...
                    medPCI, medbp);
            end  
            fprintf('\n');
        end % of make PI, there being the required data
            %
        case 4 % ------------------------------------------
%
% 6. Plot a PI diagram
% -------------------------
%
% test for existence of necessary data
            if refflag < 0.5 || PCIflag < 0.5,
                fprintf('%s\n', '--> I can''t do that yet, Dave');
            else
                % if there has been subsampling, 
                if ncompmax > 1,
                % find out which set of subsampled data is to be used
                fprintf('%s\n', ['A set of ' ...
                    num2str(ncompmax) ' PI subsamples exists;']);
                usecompn = getnum ...
                    ('  choose subsample number', ncompmax);
                if usecompn > ncompmax, usecompn = ncompmax; end
                if usecompn < 1, usecompn = 1; end
                else
                    usecompn=1;
                end
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                PIplot2(refd{usenvn}, compd{usecompn}, ...
                    refenv{usenvn,1}, refenv{usenvn,2}, ...
                    PCIdat(usecompn,:), cp);
                % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            end
            %
            %
        case 5 % ------------------------------------------
%
% 7. Change control parameters
%
    cp = CCP(cp); % Now (23 July 2015) done in separate function

        case 6 % ------------------------------------------
%
% 8. State space plot of medians (revised call, 5 Sep 2015
%
    ssplot2(data1, cp);% cp is structure with controls
%
%
        case 7 %------------------------------------------
%
% 9. Time series of PI values
%
% check for existence of reference data 
    if refflag < 0.5,
        fprintf('%s\n', '--> I can''t do that yet, my love');
    else
        % but there might be several envelope(pair)s available
        if nrefmax > 1,
            % find out what pair of envelopes is to be used
             fprintf('%s\n', ['A set of ' ...
                 num2str(nrefmax) ' envelopes exists;']);
             usenvn = getnum('  choose envelope pair number', nrefmax);
             if usenvn > nrefmax, usenvn = nrefmax; end
             if usenvn < 1, usenvn = 1; end
        else
            usenvn=1;
        end
        ncompmax = 1; % no subsampling in this case
        compd = cell(ncompmax); % cell aray - i.e. delete earlier contents
        PCIdat = zeros(ncompmax,7); % i.e. delete earlier contents
        % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        [compd{1} PCIdat(1,:)] = PITS( data1, refenv, cp );
        % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        PCIflag = 1; % now that PI have been calculated
    end
 %
 %   
        otherwise % ------------------------------------------
            fprintf('%s\n', ...
                '!! Selection not recognized: try again!');
    end % of switch (on actionflag) statements
% ============================== END SWITCH ON ACTIONFLAG ===    
end % of continueflag loop


%
% =============== THE END =====================
fprintf('\n%s\n', ['End of ' prog_name ' at ' datestr(now) '.']);
fprintf('%s\n\n', ...
        '*********************************************************');
%
% =============== END OF MAIN SCRIPT ===============
%