function [] = PCIplot...
    (refdata, compdata, envOuter, envInner, PCIdata, cd)
% PCIPLOT is called by PCI1ED3 to make a PCI diagram

% input:
%   refdata: array, 4 columns (year.dec, (transformed) y1 y2, month)
%   compdata: array, 4 columns (year.dec, (transformed) y1 y2, month)
%   envOuter: array, 2 columns - X and Y co-ords of outer envelope
%   envInner, array, 2 columns - X and Y co-ords of inner envelope
%   PCIdata, vector, 7 values: (1) and (2) - start and end dates;
%       (3) - PI; (4) and (5) total N and N outside;
%       (6) - binomial probability; (7) chi-square
%   cd: structure (see cf2.m), in which the following fields are used:
%       cd.c1svt1 : is 1, data are cells/L, if 2, they are mm3 biomass/L
%       cd.COL : if 1, selects for colour and additional text
%       cd.df1n, cd.df2n : names of (external) data files 1, 2
%       cd.d1des, cd.d2des : descriptions of file 1 or 2 data sources
%       cd.mf : controls averaging or subsampling of comparison data
%       cd.mfref : if > 0.5, apply mf also to reference data
%       cd.ndf : number of data files
%       cp.p : 1-p is outlier fraction excluded from envelope
%       cd.reff : number of data file used as reference
%       cd.refs, cd.refe : start and finish years for reference
%       cd.un : short string, user initials
%       cd.z1, cd.z2 : replaces zeros in files 1 or 2 
%       cd.sc : if 1, indicates that data have been scaled for envelope
% result is a two part diagram
%   left-hand part - reference data and envelope 
%   right-hand pat - reference envelope and comparison data

% History and authorship:
%   PT, 11-12 August 2008, using some code from PCI1ED2
%   PT, 9 August 2009, added cp.p, and minor changes to diagrams
%	PT, 25 August 2009, minor corrections
%   PT, 3 April 2010, minor updates
%   PT, 16 Aug 2011 - increased default max X (and Y)
%   PT, 29 April 2013 - better plots for biomass
%   PT, 20 May 2013 - draws lines for minima (NEEDS IMPROVEMENT)
%   PT, 6 Oct 2013 - better estimation of graph max and min
%   PT, 24 July 2015 - simplied BW output, changed print options 
%   PT, 12 Sep 2015 - displays 'PI' not 'PCI'
%
%******************************************************************
%
global prog_name uname % uname left global for consistency, but see cd
%
    clf;
	orient portrait;
	set(0, 'DefaultAxesFontName', 'times', 'DefaultAxesFontSize', 12);
%   in case cd.sc has not been set
    if not(isfield(cd, 'sc')), cd.sc = 0; end
% graph parameters (for square graphs) - updated 6 Oct 2013
    if cd.c1svt1 == 1, % using cell numbers as variable
        minX=2.0;maxX=8.0;% default - changed from 6 to 8 on 16 Aug 2011
    else % using biomass as the variable
         minX=-5.0;maxX=2.0; % added 29 April 2013
    end
    % adjust maxima and minima if necessary
     maxSV = max([max(refdata(:,2)) max(refdata(:,3)) ...
                    max(compdata(:,2)) max(compdata(:,3))] );
     if maxSV>maxX, maxX=ceil(maxSV); end
     maxY=maxX;
     minSV = min([min(refdata(:,2)) min(refdata(:,3)) ...
                    min(compdata(:,2)) min(compdata(:,3)) ...
                    log10(cd.z1)]);
     if minSV < minX, minX=floor(minSV); end
    minY=minX;
    top=maxY-0.5;% y-axis start value for legends
    edge=minX+0.3;% x-axis start value for legends
    rightedge=0.45*minX + 0.55*maxX; % x-axis right-hand start value
%
% first diagram - reference conditions
	subplot(1,2,1);
    hold on;
    if cd.COL>0.5,
        plot(refdata(:,2), refdata(:,3), 'ro--');
        plot(refdata(refdata(:,4)<4,2), ...
            refdata(refdata(:,4)<4,3),'ro', ...
                            'MarkerFaceColor','b');
        plot(refdata(refdata(:,4)>3 & refdata(:,4)<7, 2), ...
                refdata(refdata(:,4)>3 & refdata(:,4)<7, 3),'ro', ...
                        'MarkerFaceColor','g');
        plot(refdata(refdata(:,4)>6 & refdata(:,4)<10, 2), ...
                refdata(refdata(:,4)>6 & refdata(:,4)<10, 3),'ro', ...
                        'MarkerFaceColor','y');
    else
        plot(refdata(:,2), refdata(:,3), 'ko--');
    end
% plot envelope
    if cd.COL>0.5, cs='r'; else cs='k'; end
	plot(envOuter(:,1), envOuter(:,2), [cs '-'], 'LineWidth', 2);
    plot(envInner(:,1), envInner(:,2), [cs '-'], 'LineWidth', 2);
% final stuff
    axis([minX maxX minY maxY]);
    axis square;
    grid on;
% % add some legend and axis labels 
    if cd.ndf > 1 && cd.reff > 1,
        refdes = cd.d2des;
        zref = cd.z2;
    else
        refdes = cd.d1des;
        zref = cd.z1;
    end
% plot minima - added 20 May 2013 - note using z1 and maxX on both axes
    lmin = log10(zref);
    line([lmin maxX], [lmin lmin],...
        'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
    line([lmin lmin], [lmin maxX],...
         'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
% %%%%
    refdes = ['Reference: ' refdes ...
        ' (' num2str(cd.refs) ' to ' num2str(cd.refe) ')'];
    dsv1 = ['log_{10}(' cd.dsv1 ')'];
    dsv2 = ['log_{10}(' cd.dsv2 ')'];
    if cd.mfref > 0.5, 
        mfmes = ' (ref & comp)'; 
    else
        mfmes = ' (comp only)';
    end
    if cd.COL>0.5,
        if cd.sc == 1, 
            text(edge, top,'\fontname{times}\fontsize{10}scaled');
        end
        text(rightedge, top, ...
            ['\fontname{times}\fontsize{10}mf: ' ...
                num2str(cd.mf) mfmes]);
        text(rightedge, top-0.3, ...
            ['\fontname{times}\fontsize{10}p: ' num2str(cd.p,'% 4.2f')]);
        text(rightedge, top-0.6, ...
            ['\fontname{times}\fontsize{10}points: ' ...
                num2str(length(refdata(:,1)),'% 6.0f')]);
        plot(edge, top-0.3, 'ro', 'MarkerFaceColor','b');
        text(edge+0.3, top-0.3, ...
            '\fontname{times}\fontsize{10}months 1-3', 'color', 'k');
        plot(edge, top-0.6, 'ro', 'MarkerFaceColor','g');
        text(edge+0.3, top-0.6, ...
            '\fontname{times}\fontsize{10}months 4-6', 'color', 'k');
        plot(edge, top-0.9, 'ro', 'MarkerFaceColor','y');
        text(edge+0.3, top-0.9, ...
            '\fontname{times}\fontsize{10}months 7-9', 'color', 'k');
        plot(edge, top-1.2, 'ro');
        text(edge+0.3, top-1.2, ...
            '\fontname{times}\fontsize{10}months 10-12', 'color', 'k');
        text(maxX-1,lmin, ...
            '\fontname{times}\fontsize{10}min', 'color', 'r', ...
            'VerticalAlignment', 'bottom');
    end;
    title(['\fontname{times}\fontsize{14}', refdes]);
    xlabel(['\fontname{times}\fontsize{12}' dsv1]);
	ylabel(['\fontname{times}\fontsize{12}' dsv2]);
%
% plot comparison data in second diagram
	subplot(1,2,2);
    hold on;
	if cd.COL > 0.5,
        plot(compdata(:,2), compdata(:,3), 'bo--');
        plot(compdata(compdata(:,4)<4,2), ...
            compdata(compdata(:,4)<4,3),'bo', 'MarkerFaceColor','b');
        plot(compdata(compdata(:,4)>3 & compdata(:,4)<7, 2), ...
             compdata(compdata(:,4)>3 & compdata(:,4)<7, 3),'bo', ...
                        'MarkerFaceColor','g');
        plot(compdata(compdata(:,4)>6 & compdata(:,4)<10, 2), ...
            compdata(compdata(:,4)>6 & compdata(:,4)<10, 3),'bo', ...
                        'MarkerFaceColor','y');
    else
        plot(compdata(:,2), compdata(:,3), 'ko--');
    end
% plot envelope
 	if cd.COL>0.5, cs='r'; else cs='k'; end
 	plot(envOuter(:,1), envOuter(:,2), [cs '-'], 'LineWidth', 2);
    plot(envInner(:,1), envInner(:,2), [cs '-'], 'LineWidth', 2);
% plot minima - added 20 May 2013 - note using z1 and maxX on both axes
    % lmin alreday calculated (from zref)
    line([lmin maxX], [lmin lmin],...
        'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
    line([lmin lmin], [lmin maxX],...
         'Color', cs, 'Linestyle', '--', 'LineWidth', 1);
% axis stuff etc
    grid on;
	axis([minX maxX minY maxY]);
    axis square;
% add some legend and axis labels	
    if cd.ndf > 1 && cd.compf > 1,
        compdes = cd.d2des;
        compfname = cd.df2n(1:4); % for output file name
    else
        compdes = cd.d1des;
        compfname = cd.df1n(1:4);
    end
    compdes = ['Comparison: ' compdes ...
        ' (' num2str(floor(PCIdata(1))) ' to ' ...
                num2str(floor(PCIdata(2))) ')'];
 	title(['\fontname{times}\fontsize{14}' compdes]);
 	xlabel(['\fontname{times}\fontsize{12}' dsv1]);
    if cd.COL > 0.5,
    text(edge,top, ['\fontname{times}\fontsize{10}drawn by ' ...
            prog_name ' on ' date]);
 	text(edge,top-0.3, ['\fontname{times}\fontsize{10}\bfPI: ' ...
             num2str(PCIdata(3),'% 4.2f')]);
    text(edge,top-0.6, ['\fontname{times}\fontsize{10}new points: ' ...
             num2str(PCIdata(4),'% 5.0f')]);
% binomial probability
        text(rightedge,top-0.3, ...
            ['\fontname{times}\fontsize{10}binom p: '...
                num2str(PCIdata(6),'%6.4f')]);
% chi-square
        text(rightedge,top-0.6, ...
            ['\fontname{times}\fontsize{10}chi-sq: '...
                num2str(PCIdata(7),'%6.1f') ' (df=1)']);	
    end
%   output the 2-part diagram
    orient portrait
    cal = fix(clock); 
    hrminsec = ['-' num2str(cal(4)) '-' num2str(cal(5)) ...
                        '-' num2str(cal(6))];
    if exist('cd.un', 'var'), uname = cd.un; end
    ofn = [uname, prog_name, '-', compfname, ...
                 num2str(floor(PCIdata(1))), hrminsec, '.', cd.pt];
 % Print options changed, 24 July 2015
    switch cd.pt
 %       case 'ai' 
 %           print('-dill', ofn);
        case 'pdf'
            print('-dpdf', ofn);
        case 'ps'
            print('-dpsc2', ofn);
        case 'eps'
            print('-depsc2', ofn);
        case 'svg'
            print('-dsvg', ofn);
        otherwise
            fprintf('\n%s\n',' ---- printing error');
    end % of switch
    fprintf('\n%s\n\n', ['===== PI plot saved as ' ofn]);
%

