function [finald finalPI] = PITS( inputd, envl, LCP )
% PITS calculates (and plots) time-series of PI values and statistics
%   PT, 23-25 July 2015
%   Updated 11 Sep 2015 (revised call of EXTRACT and dealing with biomass)
%
%   INPUT
%       inputd = the file of 'raw' data containing Y1 and Y2 abundances
%       env = data defining the reference envelope
%       LCP - structure containing control parameters
%   OUTPUT
%       finald = the final year's abundances of the Y1 and Y2 variables
%       finalPI = the final year's PI statistics
%
%   NOTES
%       returns (mostly) NaN when number of data for a year are fewer
%       than LCP.mindata

global prog_name uname

%% A. start-up
 mf = max( 0, LCP.mf);% don't allow -ve mf, i.e. no random subsampling      
 fprintf('%s\n', ['Estimating PI time-series with mf = ', num2str(mf)]);
 mess = [LCP.d1des ' from file ' LCP.df1n];
 fprintf('%s\n', ['  using data for ' mess]);
 
 if LCP.c1svt1 == 1, % dealing will cell numbers
     z1 = LCP.z1; z2 = LCP.z2;
 else % dealing with biomasses
     z1 = LCP.bz1; z2 = LCP.bz2;
 end
     
%% B. get start and end years

years = unique(floor(inputd(:,1)));
minyear = min(years); maxyear = max(years);
fprintf('%s\n', 'Select range of years for annual PI time-series:');
comp_start = floor(getnum('Enter (integer) start year', minyear));
    if comp_start < minyear, comp_start = minyear; end
    if comp_start > maxyear, comp_start = maxyear; end
comp_end = floor(getnum('Enter (integer) end year', maxyear));
     if comp_end < comp_start, comp_end = comp_start; end
     if comp_end > maxyear, comp_end = maxyear; end
fprintf('%s\n', ['--- using the year range: ' ...
            num2str(comp_start) ' to ' num2str(comp_end)]);
fprintf(...
    '        year          PI    N-total N-out  binom p  chi-sq \n');
%
%% C. step through years, extracting data, checking sufficiency,
%       and then calculating PI
dur = comp_end - comp_start + 1;
PIdat = zeros(dur, 7); nn = 1; % rows are years, columns are values
for year = comp_start : comp_end,
     PIdat(nn, 1) = year;   PIdat(nn, 2) = year;
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    locald =  extract2(year, year, z1, z2, ...
                inputd, LCP.c1dat, LCP.c1sv1, LCP.c1sv2, mf);
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    Ndat = length(locald(:,4));
    if Ndat >= LCP.mindata,
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        PIdat(nn, 3:7) = PCIcalc2(locald, envl{1}, envl{2}, LCP.p);
    % returns: PI, n-total, n-out, binom sig, chi-sq 
    % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    else
        PIdat(nn, 3:7) = [NaN Ndat NaN NaN NaN];
    end
    fprintf('%8.2f %8.2f %8.2f %6.0f %6.0f %8.4f %8.2f \n', PIdat(nn,:));
    nn = nn+1;
end
fprintf('\n');  
%
%% D. plot time-series of PI (if more than, say, 2 years); show ref period
%
if length(PIdat(isfinite(PIdat(:,3)),3)) > 2,
    clf
    % determine length of plot, including reference years
    startplot = min(comp_start, LCP.refs) - 1;
    endplot = max(comp_end, LCP.refe) + 1;
    Xlim = [startplot endplot];
    Xwidth = endplot - startplot;
    Ylim = [-0.1 1.1];
    % work out which PI points are significantly different
    sig = 0.01; % or as desired
    PIdatsig = PIdat(:,6) < sig;
    % plot the graph
    plot(PIdat(:,1), PIdat(:,3), 'ko-'); % all PI values
    hold on
    plot(PIdat(PIdatsig,1), PIdat(PIdatsig,3), 'ko', ...
        'MarkerFaceColor','k'); % significant PI values
    % add other features
    grid on
    line(Xlim, [1.0 1.0], 'Linestyle', '-', 'Linewidth', 1, 'Color', 'k');
    line(Xlim, [0.0 0.0], 'Linestyle', '-', 'Linewidth', 1, 'Color', 'k');
    line(Xlim, [LCP.p LCP.p], 'Linestyle', '--', 'Color', 'r');
    text((startplot + 0.8*Xwidth), LCP.p, ...
        '\fontname{times}\fontsize{12}no change', 'Color', 'r', ...
            'BackgroundColor', 'w'); 
    line([LCP.refs LCP.refs], [0 1], 'Linestyle', '-', ...
        'Linewidth', 1, 'Color', 'g');
    line([LCP.refe LCP.refe], [0 1], 'Linestyle', '-', ...
        'Linewidth', 1, 'Color', 'g');
    text((LCP.refs - 0.02*Xwidth), 0.15, ...
        ['\fontname{times}\fontsize{10}' num2str(LCP.refs) ' - ' ...
            num2str(LCP.refe)], 'Color', 'g', 'BackgroundColor', 'w'); 
    text((LCP.refs - 0.02*Xwidth), 0.2, ...
        '\fontname{times}\fontsize{12}reference', 'Color', 'g',...
            'BackgroundColor', 'w'); 
    plot(comp_start, -0.05, 'ko', 'MarkerFaceColor', 'k');
    text((comp_start+0.02*Xwidth), -0.05, ...
       [ '\fontname{times}\fontsize{12}significant change, p < ' ...
            num2str(sig)],'BackgroundColor', 'w'); 
    axis([Xlim Ylim]);
    title(['\fontname{times}\fontsize{14}', LCP.d1des]);
    xlabel('\fontname{times}\fontsize{12}year');
	ylabel('\fontname{times}\fontsize{12}PI');
else
    fprintf('%s\n', '--Insufficient data for graph');
end

%% E. Finish - print and output

ofn = [uname prog_name '-PIts'];
    
PIPrint(LCP.pt, ofn, 'PI time-series' ); % call printing function

finald = locald; % output last used data set
finalPI = PIdat(nn-1,:); % output last set of PI data

end

